@@ -1,9 +1,8 @@
 from jaseci.actions.live_actions import jaseci_action
 from jaseci.svcs.mail.mail_svc import mail_svc
+from jaseci.svcs.common_svc import MAIL_ERR_MSG
 from jaseci.utils.utils import logger
 
-MAIL_ERR_MSG = "Mail service is disabled or not yet configured!"
-
 
 @jaseci_action()
 def send(sender, recipients, subject, text, html, meta):
