@@ -10,7 +10,11 @@ class super_api:
 
     @interface.admin_api(cli_args=["name"])
     def master_createsuper(
-        self, name: str, set_active: bool = True, other_fields: dict = {}
+        self,
+        name: str,
+        global_init: str = "",
+        global_init_ctx: dict = {},
+        other_fields: dict = {},
     ):
         """
         Create a super instance and return root node super object
@@ -18,10 +22,18 @@ class super_api:
         other_fields used for additional feilds for overloaded interfaces
         (i.e., Dango interface)
         """
-        from jaseci.element.super_master import super_master
-
-        new_m = super_master(h=self._h, name=name)
-        return self.make_me_head_master_or_destroy(new_m)
+        if self.sub_master_ids.has_obj_by_name(name):
+            return {"response": f"{name} already exists", "success": False}
+        ret = {}
+        mast = self.superuser_creator(name, other_fields)
+        ret["user"] = mast.serialize()
+        if len(global_init):
+            ret["global_init"] = self.user_global_init(
+                mast, global_init, global_init_ctx
+            )
+        self.take_ownership(mast)
+        ret["success"] = True
+        return ret
 
     @interface.admin_api()
     def master_allusers(self, num: int = 0, start_idx: int = 0):
