@@ -1,8 +1,5 @@
 from jaseci.utils.test_core import core_test
 import jaseci.tests.jac_test_code as jtc
-from jaseci.element.master import master
-from jaseci.utils.mem_hook import mem_hook
-from jaseci.element.super_master import super_master
 
 
 class global_api_test(core_test):
@@ -12,11 +9,12 @@ class global_api_test(core_test):
 
     def setUp(self):
         super().setUp()
-        self.smast2 = super_master(h=self.smast._h)
+
+        self.smast2 = self.meta.super_master(h=self.smast._h)
         self.smast.sentinel_register(name="test", code=jtc.basic)
 
-        self.mast = master(h=mem_hook())
-        self.mast2 = super_master(h=self.mast._h)
+        self.mast = self.meta.master()
+        self.mast2 = self.meta.super_master(h=self.mast._h)
         self.mast.sentinel_register(name="test", code=jtc.basic)
 
     def tearDown(self):
