@@ -62,7 +62,7 @@ class walker_interp(interp):
             act_list += i.exit_action_ids
         self.auto_trigger_node_actions(nd=self.current_node, act_list=act_list)
 
-        if kid[-2].name == "walk_exit_block":
+        if not self.yielded and kid[-2].name == "walk_exit_block":
             self.run_walk_exit_block(kid[-2])
 
     def run_node_ctx_block(self, jac_ast):
@@ -108,17 +108,12 @@ class walker_interp(interp):
         walker_action:
             ignore_action
             | take_action
-            | KW_DISENGAGE (report_action | SEMI);
+            | disengage_action
+            | yield_action;
         """
         kid = self.set_cur_ast(jac_ast)
-        if kid[0].name == "KW_DISENGAGE":
-            if kid[1].name == "report_action":
-                self.run_report_action(kid[1])
-            self._stopped = "stop"
-            self.next_node_ids.remove_all()
-        else:
-            expr_func = getattr(self, f"run_{kid[0].name}")
-            expr_func(kid[0])
+        expr_func = getattr(self, f"run_{kid[0].name}")
+        expr_func(kid[0])
 
     def run_ignore_action(self, jac_ast):
         """
@@ -168,6 +163,32 @@ class walker_interp(interp):
             self.run_else_stmt(kid[2])
         after = len(self.next_node_ids)
 
+    def run_disengage_action(self, jac_ast):
+        """
+        disengage_action: KW_DISENGAGE (report_action | SEMI);
+        """
+        kid = self.set_cur_ast(jac_ast)
+        if kid[1].name == "report_action":
+            self.run_report_action(kid[1])
+        self._stopped = "stop"
+        self.next_node_ids.remove_all()
+
+    def run_yield_action(self, jac_ast):
+        """
+        yield_action:
+            KW_YIELD (
+                report_action
+                | disengage_action
+                | take_action
+                | SEMI
+            );
+        """
+        kid = self.set_cur_ast(jac_ast)
+        if kid[1].name != "SEMI":
+            expr_func = getattr(self, f"run_{kid[1].name}")
+            expr_func(kid[1])
+        self.yield_walk()
+
     def run_preset_in_out(self, jac_ast, obj, act):
         """
         preset_in_out:
