@@ -1,11 +1,9 @@
 from antlr4 import InputStream, CommonTokenStream
 from jaseci.jac.jac_parse.jacLexer import jacLexer
 from jaseci.jac.jac_parse.jacParser import jacParser
-from jaseci.utils.mem_hook import mem_hook
+from jaseci.svcs.meta_svc import meta_svc
 from jaseci.actor.sentinel import sentinel
 from jaseci.graph.graph import graph
-from jaseci.element.super_master import super_master
-from jaseci.element.master import master
 import jaseci.actions.live_actions as lact
 import os
 
@@ -19,6 +17,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def setUp(self):
         super().setUp()
+        self.meta = meta_svc()
 
     def tearDown(self):
         super().tearDown()
@@ -34,7 +33,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_jac_code(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         self.assertIsNotNone(sent.walker_ids.get_obj_by_name("get_gen_day"))
@@ -42,7 +41,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_jac_code_multiple_times(self):
         """Test registering resets correctly for multiple attempts"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog0)
         num_walkers = len(sent.walker_ids)
@@ -56,7 +55,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_register_dep_on_static_errors(self):
         """Test Jac registering is dependant on correct static/dynamic code"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         correct = "node b { has anchor a; }"
         wrong1 = "adfdsf"
@@ -73,7 +72,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_loading_arhitype(self):
         """Test the generation of jaseci trees for programs in grammar"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         self.assertGreater(
@@ -82,7 +81,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_running_basic_walker(self):
         """Test the execution of a basic walker building graph"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
@@ -99,7 +98,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_setp_running_walker(self):
         """Test the execution of a basic walker building graph"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
@@ -123,7 +122,7 @@ class jac_tests(TestCaseHelper, TestCase):
         """
         Test that  no loss or gain of data on second trak on second trek
         """
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
@@ -146,7 +145,7 @@ class jac_tests(TestCaseHelper, TestCase):
         scalably (node contexts dont get deleted when arch_ids deleted)
         """
         lact.load_local_actions(os.path.dirname(__file__) + "/infer.py")
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("life", kind="node").run()
@@ -164,7 +163,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sent_loads_complex_walker_and_arch(self):
         """Test loading attributes of arch and walkers"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.prog1)
         test_node = sent.arch_ids.get_obj_by_name("testnode", kind="node").run()
@@ -175,11 +174,11 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_availabilty_of_global_functions(self):
         """Test preset function loading"""
-        self.assertGreater(len(mem_hook().global_action_list), 10)
+        self.assertGreater(len(self.meta.hook().global_action_list), 10)
 
     def test_multiple_edged_between_nodes_work(self):
         """Test that multiple edges between the same two nodes are allowed"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -194,7 +193,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey2)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -205,7 +204,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_specific(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey2b)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -216,7 +215,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_all_labeled(self):
         """Test that multiple edges deleted correctly if delete all"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey2c)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -227,7 +226,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_multiple_edged_between_nodes_delete_filtered(self):
         """Test that multiple edges deleted correctly if delete filtered"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey3)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -238,7 +237,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_generic_can_be_used_to_specify_generic_edges(self):
         """Test that generic edge tag works"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey4)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -249,7 +248,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_simultaneously(self):
         """Test disconnecting mutilpe nodes"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey5)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -260,7 +259,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_can_connect_multi_nodes_simultaneously(self):
         """Test connecting mutilpe nodes"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey6)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -271,7 +270,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_can_disconnect_multi_nodes_advanced(self):
         """Test disconnecting mutilpe nodes advanced"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edgey7)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -282,7 +281,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_accessing_edges_basic(self):
         """Test accessing Edges"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edge_access)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -298,7 +297,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_has_assign(self):
         """Test assignment on definition"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.has_assign)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -315,7 +314,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_global_get_set(self):
         """Test assignment on definition"""
-        mast = super_master(h=mem_hook())
+        mast = self.meta.super_master()
         gph = graph(m_id=mast.jid, h=mast._h)
         sent = sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.set_get_global)
@@ -329,7 +328,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_global_set_requires_admin(self):
         """Test assignment on definition"""
-        mast = master(h=mem_hook())
+        mast = self.meta.master()
         gph = graph(m_id=mast.jid, h=mast._h)
         sent = sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.set_get_global)
@@ -343,7 +342,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_sentinel_version_label(self):
         """Test sentinel version labeling"""
-        mast = master(h=mem_hook())
+        mast = self.meta.master()
         gph = graph(m_id=mast.jid, h=mast._h)
         sent = sentinel(m_id=mast.jid, h=gph._h)
         sent.register_code(jtc.version_label)
@@ -351,7 +350,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_visibility_builtins(self):
         """Test builtins to see into nodes and edges"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.visibility_builtins)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -364,7 +363,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_spawn_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.spawn_ctx_edge_node)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -377,7 +376,7 @@ class jac_tests(TestCaseHelper, TestCase):
 
     def test_filter_ctx_for_edges_nodes(self):
         """Test builtins to see into nodes and edges"""
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.filter_ctx_edge_node)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -387,7 +386,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.report[1]), 0)
 
     def test_null_handling(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.null_handleing)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -399,7 +398,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[3], False)
 
     def test_bool_type_convert(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.bool_type_convert)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -409,7 +408,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(True, test_walker.report[1]["name"])
 
     def test_typecasts(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.typecasts)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -423,7 +422,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report[5], "Types comes back correct")
 
     def test_typecast_error(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.typecasts_error)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -436,7 +435,7 @@ class jac_tests(TestCaseHelper, TestCase):
         )
 
     def test_filter_on_context(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.filter_on_context)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -447,7 +446,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertIn("name", test_walker.report[0][2].keys())
 
     def test_string_manipulation(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.string_manipulation)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -486,7 +485,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[29], True)
 
     def test_list_manipulation(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.list_manipulation)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -506,7 +505,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[10], [])
 
     def test_list_reversed(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.list_reversed)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -517,7 +516,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[1], [4, 2, 7])
 
     def test_dict_manipulation(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.dict_manipulation)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -534,7 +533,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[7], {})
 
     def test_string_join(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.string_join)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -544,7 +543,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0], "test_me_now")
 
     def test_sub_list(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.sub_list)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -556,7 +555,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[0][2], 7)
 
     def test_destroy_and_misc(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.destroy_and_misc)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -581,7 +580,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[9], True)
 
     def test_arbitrary_assign_on_element(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.arbitrary_assign_on_element)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -593,7 +592,7 @@ class jac_tests(TestCaseHelper, TestCase):
         )
 
     def test_try_else_stmts(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.try_else_stmts)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -618,7 +617,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep[3], 2)
 
     def test_node_edge_same_name(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.node_edge_same_name)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -631,7 +630,7 @@ class jac_tests(TestCaseHelper, TestCase):
         )
 
     def test_testcases(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.testcases)
         sent.run_tests(silent=True)
@@ -640,7 +639,7 @@ class jac_tests(TestCaseHelper, TestCase):
             self.assertEqual(i["passed"], True)
 
     def test_testcase_asserts(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.testcase_asserts)
         sent.run_tests(silent=True)
@@ -650,7 +649,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(sent.testcases[2]["passed"], False)
 
     def test_report_not_to_jacset(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.report_not_to_jacset)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -661,7 +660,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertIn("j_type", rep[0][0].keys())
 
     def test_walker_spawn_unwrap_check(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.walker_spawn_unwrap_check)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -671,7 +670,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertTrue(rep[0].startswith("urn:uuid"))
 
     def test_std_get_report(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.std_get_report)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -681,7 +680,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep, [3, 5, 6, 7, [3, 5, 6, 7], 8])
 
     def test_func_with_array_index(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.func_with_array_index)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -691,7 +690,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(rep, [3, 5, 3])
 
     def test_rt_error_test1(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.rt_error_test1)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -702,7 +701,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertIn(" col ", test_walker.runtime_errors[0])
 
     def test_root_type_nodes(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.root_type_nodes)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -712,7 +711,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report, ["root", "root"])
 
     def test_invalid_key_error(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.invalid_key_error)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -722,7 +721,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertGreater(len(errors), 0)
 
     def test_auto_cast(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.auto_cast)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -732,7 +731,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report, [True, True])
 
     def test_no_error_on_dict_key_assign(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.no_error_on_dict_key_assign)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -743,7 +742,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(test_walker.runtime_errors), 0)
 
     def test_report_status(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.report_status)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -754,7 +753,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(test_walker.report_status, 302)
 
     def test_graph_in_graph(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.graph_in_graph)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -764,7 +763,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(report), 3)
 
     def test_min_max_on_list(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.min_max_on_list)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -774,7 +773,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(report, [531.1, 3, 5, 1])
 
     def test_edge_bug(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.edge_bug)
         test_walker = sent.walker_ids.get_obj_by_name("init")
@@ -784,7 +783,7 @@ class jac_tests(TestCaseHelper, TestCase):
         self.assertEqual(len(report[0]), 4)
 
     def test_rand_choice(self):
-        gph = graph(m_id="anon", h=mem_hook())
+        gph = graph(m_id="anon", h=self.meta.hook())
         sent = sentinel(m_id="anon", h=gph._h)
         sent.register_code(jtc.rand_choice)
         test_walker = sent.walker_ids.get_obj_by_name("init")
