@@ -1,10 +1,9 @@
+from jaseci.svcs.meta_svc import meta_svc
 from jaseci.utils.utils import TestCaseHelper
 from unittest import TestCase
 from jaseci.graph.node import node
 from jaseci.attr import action
 from jaseci.graph.edge import edge
-from jaseci.element import element
-from jaseci.utils.mem_hook import mem_hook
 from jaseci.actor.architype import architype
 
 
@@ -13,13 +12,14 @@ class node_tests(TestCaseHelper, TestCase):
 
     def setUp(self):
         super().setUp()
+        self.meta = meta_svc()
 
     def tearDown(self):
         super().tearDown()
 
     def test_node_connections(self):
         """Test connecting and disconnecting etc of nodes"""
-        node1 = node(m_id="anon", h=mem_hook())
+        node1 = node(m_id="anon", h=self.meta.hook())
         node2 = node(m_id="anon", h=node1._h)
         node3 = node(m_id="anon", h=node1._h)
         node4 = node(m_id="anon", h=node1._h)
@@ -48,7 +48,7 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_add_context_to_node_and_destroy(self):
         """Test adding and removing contexts nodes"""
-        node1 = node(m_id="anon", h=mem_hook())
+        node1 = node(m_id="anon", h=self.meta.hook())
         node1.context["yeah dude"] = "SUP"
         self.assertEqual(node1.context["yeah dude"], "SUP")
         self.assertEqual(len(node1.context.keys()), 1)
@@ -57,7 +57,7 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_add_entry_action_to_node_and_destroy(self):
         """Test connecting and disconnecting etc of nodes"""
-        node1 = architype(m_id="anon", h=mem_hook())
+        node1 = architype(m_id="anon", h=self.meta.hook())
         act = action.action(m_id="anon", h=node1._h, name="yeah dude", value="SUP")
         node1.entry_action_ids.add_obj(act)
         self.assertEqual(
@@ -73,7 +73,7 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_adding_and_removing_from_hdnodes(self):
         """Test adding nodes and removing them from HDGDs"""
-        node1 = node(m_id="anon", h=mem_hook())
+        node1 = node(m_id="anon", h=self.meta.hook())
         hdgd1 = node(m_id="anon", h=node1._h, name="yeah dude", dimension=1)
         node1.make_member_of(hdgd1)
         self.assertEqual(node1.parent_node_ids.obj_list()[0], hdgd1)
@@ -88,14 +88,14 @@ class node_tests(TestCaseHelper, TestCase):
 
     def test_dimensions_must_match_to_connect_nodes(self):
         """Test dimension matching requirement for node connection"""
-        node1 = node(m_id="anon", h=mem_hook())
+        node1 = node(m_id="anon", h=self.meta.hook())
         hdgd1 = node(m_id="anon", h=node1._h, name="yeah dude", dimension=1)
         node1.attach_outbound(hdgd1)
         self.assertFalse(node1.is_attached_out(hdgd1))
 
     def test_inherit_from_element_edge(self):
         """Test that inheriting params with kwargs works"""
-        hook = element.mem_hook()
+        hook = self.meta.hook()
         a = edge(
             name="my edge",
             m_id="anon",
